<?php
/** Kashmiri (Arabic script) (کٲشُر)
 *
 * To improve a translation please visit https://translatewiki.net
 *
 * @ingroup Language
 * @file
 *
 * @author Rachitrali
 * @author Rk_kaul (on ks.wikipedia.org)
 * @author VibhasKS
 */

$rtl = true;

$namespaceNames = [
	NS_MEDIA            => 'میڈیا',
	NS_SPECIAL          => 'خاص',
	NS_TALK             => 'بَحَژ',
	NS_USER             => 'رُکُن',
	NS_USER_TALK        => 'رُکُن_بَحَژ',
	NS_PROJECT_TALK     => '$1_بَحَژ',
	NS_FILE             => 'فَیِل',
	NS_FILE_TALK        => 'فَیِل_بَحَژ',
	NS_MEDIAWIKI        => 'میڈیاوکی',
	NS_MEDIAWIKI_TALK   => 'میڈیاوکی_بَحَژ',
	NS_TEMPLATE         => 'فرما',
	NS_TEMPLATE_TALK    => 'فرما_بَحَژ',
	NS_HELP             => 'پَلزُن',
	NS_HELP_TALK        => 'پَلزُن_بَحَژ',
	NS_CATEGORY         => 'زٲژ',
	NS_CATEGORY_TALK    => 'زٲژ_بَحَژ',
];

$digitTransformTable = [
	'0' => '٠', # &#x0660;
	'1' => '١', # &#x0661;
	'2' => '٢', # &#x0662;
	'3' => '٣', # &#x0663;
	'4' => '٤', # &#x0664;
	'5' => '٥', # &#x0665;
	'6' => '٦', # &#x0666;
	'7' => '٧', # &#x0667;
	'8' => '٨', # &#x0668;
	'9' => '٩', # &#x0669;
];

$separatorTransformTable = [
	'.' => '٫', # &#x066b;
	',' => '٬', # &#x066c;
];
